using Infragistics;
using Infragistics.Controls.Schedules;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace xamSchedule_sample
{
    public class ViewModel
    {
        public ObservableCollection<Resource> Resources { get; set; }
        public ObservableCollection<ResourceCalendar> Calendars { get; set; }
        public ObservableCollection<Appointment> Appointments { get; set; }
        public ListScheduleDataConnector DataConnector { get; set; }
        
        public DateRange? CurrentTimeRange { get; set; } 

        public ViewModel()
        {
            Resources = new ObservableCollection<Resource>();
            Calendars = new ObservableCollection<ResourceCalendar>();
            Appointments = new ObservableCollection<Appointment>();

            // Adding a resource
            Resource resMain = new Resource() { Id = "own1", Name = "MyMainCalendar" };
            Resources.Add(resMain);

            // Adding a calendar
            ResourceCalendar calMain = new ResourceCalendar()
            {
                Id = "cal1",
                OwningResourceId = "own1"
            };
            Calendars.Add(calMain);

            // Adding Appointments for MyMainCalendar
            Appointment app1 = new Appointment()
            {
                Id = "t1",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "IT Consulting",
                Description = "IT consulting appointment.",
                Start = DateTime.Today.AddHours(10).AddMinutes(00).ToUniversalTime(),
                End = DateTime.Today.AddHours(11).AddMinutes(00).ToUniversalTime()
            };
            Appointment app2 = new Appointment()
            {
                Id = "t2",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "HR Consulting",
                Description = "HR consulting appointment.",
                Start = DateTime.Today.AddHours(14).AddMinutes(00).ToUniversalTime(),
                End = DateTime.Today.AddHours(16).AddMinutes(00).ToUniversalTime()
            };
            Appointments.Add(app1);
            Appointments.Add(app2);

            Appointment app3 = new Appointment()
            {
                Id = "t3",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Conflict meeting 1",
                Description = "This is a conflict meeting.",
                Start = DateTime.Today.AddHours(12).AddMinutes(00).ToUniversalTime(),
                End = DateTime.Today.AddHours(13).AddMinutes(00).ToUniversalTime()
            };
            Appointment app4 = new Appointment()
            {
                Id = "t4",
                OwningResourceId = "own1",
                OwningCalendarId = "cal1",
                Subject = "Conflict meeting 2",
                Description = "This is another conflict meeting.",
                Start = DateTime.Today.AddHours(12).AddMinutes(00).ToUniversalTime(),
                End = DateTime.Today.AddHours(13).AddMinutes(00).ToUniversalTime()
            };
            Appointments.Add(app3);
            Appointments.Add(app4);

            // Attaching the Resources, Calendars and Appointments to the dataConnector
            DataConnector = new ListScheduleDataConnector();
            DataConnector.ResourceItemsSource = Resources;
            DataConnector.ResourceCalendarItemsSource = Calendars;
            DataConnector.AppointmentItemsSource = Appointments;
        }
    }
}
